@@ -22,10 +22,10 @@
 extern "C" {
 #endif
 
-#define RC_PREFIX "/usr"
+#define RC_PREFIX ""
 #define RC_SYSCONFDIR		"/etc"
-#define RC_LIBDIR               "/usr/lib64/rc"
-#define RC_LIBEXECDIR           "/usr/lib/rc"
+#define RC_LIBDIR               "/lib64/rc"
+#define RC_LIBEXECDIR           "/lib/rc"
 #if defined(PREFIX)
 #define RC_SVCDIR               RC_LIBEXECDIR "/init.d"
 #elif defined(__linux__) || (defined(__FreeBSD_kernel__) && \
